#################
External packages
#################

GWpy provides optional integration with many external packages to enhance its functionality.
These packages are not required for the core features of GWpy but can be installed to
enable additional capabilities.

Many of the external packages can be installed via pip alongside GWpy
(see :ref:`gwpy-install-optional`),
however some packages are not available on PyPI and must be installed separately.
Instructions for installing these packages can be found in the relevant sections below.

.. toctree::
    :glob:

    *
